@@ -1,4 +1,4 @@
-denplot <- function(mcmcout, parms=NULL, regex=NULL, random=NULL, xlim=NULL, ylim=NULL, auto.layout=TRUE, mar=c(2.0, 2.0, 1.5, 0.25)+0.1, col=mcmcplotsPalette(nchains), lty=1, xlab="", ylab="", main=NULL, collapse=FALSE, style=c("gray", "plain"), ...){
+denplot <- function(mcmcout, parms=NULL, regex=NULL, random=NULL, xlim=NULL, ylim=NULL, auto.layout=TRUE, mar=c(2.0, 2.0, 1.5, 0.25)+0.1, col=mcmcplotsPalette(nchains), lty=1, xlab="", ylab="", plot.title=NULL, main=NULL, collapse=FALSE, style=c("gray", "plain"), ...){
     gpar.args <- list(...)
     style <- match.arg(style)
 
@@ -17,11 +17,17 @@ denplot <- function(mcmcout, parms=NULL, regex=NULL, random=NULL, xlim=NULL, yli
     p <- length(parnames)
 
     if (auto.layout){
-        op <- mult.fig(p, main=main, mar=mar)$old.par
+        op <- mult.fig(p, main=plot.title, mar=mar)$old.par
         on.exit(par(op))
     }
+    if (is.null(main)){
+        main <- parnames
+        names(parnames) <- main
+    }
+    main <- rep(main, length.out=length(parnames))
+    names(main) <- parnames
     for (pmtr in parnames){
-        gpar <- c(list(xlim=xlim, ylim=ylim, xlab=xlab, ylab=ylab, main=pmtr), gpar.args)
+        gpar <- c(list(xlim=xlim, ylim=ylim, xlab=xlab, ylab=ylab, main=main[pmtr]), gpar.args)
         denoverplot1(mcmcout[, pmtr, drop=FALSE], col=col, lty=lty, style=style, gpar=gpar)
     }
     return(invisible(parnames))
